@@ -6,6 +6,9 @@
 #' @noRd
 read_md5file <- function(md5path) {
     
+    if (!file.exists(md5path))
+        stop("The file path you specified does not seem to exist: '", md5path,"'.", call. = FALSE)
+    
     file <-
         readr::read_delim(
             md5path,
